<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ms">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Padam</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">Skrin penuh</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Persembahan slaid</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksport</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Salin</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Kegemaran</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Putar lawan jam</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Tetap sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Maklumat foto</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Pulih</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Tidak bernama</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Cipta</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Album Baharu</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Anda pasti mahu memadam album ini?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Tong Sampah</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Tong Sampah</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Atau seret foto di sini</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Import Semua</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Import ke:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Cakera Sistem</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeri</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Cakera sibuk, tidak dapat lenting sekarang</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Abai</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ganti</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Gambar</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Dokumen</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Muat turun</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Atas Meja</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Muzik</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nama:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Simpan ke:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Kualiti:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Pilih direktori lain</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Nama fail tidak boleh kosong</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>sudah wujud. Anda mahu menggantikannya?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>Pemacu %1</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Cakera %1 Kosong</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1 Disulitkan</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>Volum %1</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Simpan</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Eksport Foto</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Memadam...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Memulihkan...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Maklumat asas</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Perincian</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Import Foto dan Video</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Atau seret di sini</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Semua foto dan video</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Persembahan slaid</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nama semula</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Peranti</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galeri</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Album ialah sebuah pengurus bergaya untuk melihat dan mengurus gambar dan video.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Persembahan slaid</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetap sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Terdahulu</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Berikutnya</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Nama semula album</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Album “%1” dibuang</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Berjaya ditambah ke dalam &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Import berjaya</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Import gagal</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksport gagal</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Eksport berjaya</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Semua Foto</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Garis Masa</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Keluar skrin penuh/persembahan slaid</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Papar pintasan</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Pilih semua</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zum masuk</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zum keluar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Halaman atas</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Halaman bawah</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Tetapan</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Mengimport...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Semua foto dan video</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Import Foto dan Video</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Denyar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Saiz fail</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensi</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Tarikh ditangkap</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tarikh diubah suai</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mod dedahan</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program dedahan</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Masa dedahan</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Bukaan</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Panjang fokus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Bukaan maks.</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mod pemeteran</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Imbangan putih</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Pemampasan denyar</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model kanta</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Ruang warna</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Tiada keputusan</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Cakera Sistem</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Nyahpilih</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Diimport pada</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Diimport pada</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Pilih Semua</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Nyahpilih Semua</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Pulih</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Semua</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Tiada keputusan</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Mengimport...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 item diimport</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 item dipadamkan</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 item diimport, %2 item gagal</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 foto terpilih</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 video terpilih</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Foto/video sudah wujud</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>%n foto terpilih</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>%n video terpilih</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>%n item terpilih</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 item diimport, %2 item sudah ada</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Humans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Animals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scene</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plants</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Tiada keputusan gelintar</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Persembahan Slaid</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Keputusan gelintar</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>1 foto ditemui</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>%n video ditemui</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>1 video ditemui</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>%n item ditemui</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Lihat</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Skrin penuh</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksport</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Kegemaran</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nyahgemar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Putar ikut jam</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Putar lawan jam</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Papar dalam pengurus fail</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Tetap sebagai kertas dinding</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Padam</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Persembahan slaid</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Maklumat foto</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Tambah ke album</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Buang daripada album</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Pulih</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album baharu</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Cetak</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation>hari</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 foto</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 video</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n foto</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n video</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>%n item</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Maklumat asas</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Tarikh diubah suai</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Jenis</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Saiz fail</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Tarikh ditangkap</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
